#!/bin/sh

# Copyright (C) 2009 IBM, Inc. 

if [ -e /images/setupScripts/debug ]; then
   set -x
   set -v
fi

if [ -e /images/work_files/.password ]; then
   source /images/work_files/.password
else
   echo "$(date) Error, .password file not found."
   exit 1
fi

if [ -z "$1" ]; then 
   echo "Usage: $0 new password"
   exit 1
fi 

echo "Did you run TFAM_shutdown.sh before running this script? (Yes/No)"
read x more

if [ $x != "Yes" ]; then
   echo "The appliance processes must be stopped before reconfiguration. Run TFAM_shutdown.sh first."
  exit 1
fi


NEWPASSWD=$1

IMAGES=/images
WORKFILES=$IMAGES/work_files
SCRIPTS=$IMAGES/setupScripts
ITMHOME=/opt/IBM/ITM
ITMCMD=$ITMHOME/bin/itmcmd

TCRHOME=/opt/IBM/tivoli/tip
TRCMD=$TCRHOME/products/tcr/bin/trcmd.sh 
TCRBIN=$TCRHOME/products/tcr/bin
TIPBIN=$TCRHOME/profiles/TIPProfile/bin
TIPCELL=$TCRHOME/profiles/TIPProfile/config/cells/TIPCell


#
# Backup originals and update the password file
#
cp $WORKFILES/.password $WORKFILES/.password.bak

sed --in-place "s/export PASSWD=$PASSWD/export PASSWD=$NEWPASSWD/g" $WORKFILES/.password
sed --in-place "s/export TIPPASSWD=$PASSWD/export TIPPASSWD=$NEWPASSWD/g" $WORKFILES/.password
sed "s/@PASSWORD@/$NEWPASSWD/g" $SCRIPTS/tipadmin_password.jacl.in > $SCRIPTS/tipadmin_password.jacl


#
# Prepare silent install/config files with password
#
$IMAGES/setupScripts/prep_silent_files.sh $NEWPASSWD
retcode=$?
if [ $retcode -ne 0 ] ; then
  echo "$(date) Password setup failed. Stopping setup."
  exit 1
fi

#
# Change password for OS accounts
#
echo -e "$NEWPASSWD\n$NEWPASSWD" | passwd sysadmin --stdin
echo -e "$NEWPASSWD\n$NEWPASSWD" | passwd itmuser --stdin
echo -e "$NEWPASSWD\n$NEWPASSWD" | passwd db2inst1 --stdin
echo -e "$NEWPASSWD\n$NEWPASSWD" | passwd nobody --stdin

#
# Reconfigure ITM TEPS
#

# DB2 must be running for TEPS configuration
su - db2inst1 -c 'db2start'
#
$ITMCMD config -A -p $WORKFILES/tmv_cq_silent_config.txt cq

#
# Reconfigure ITM's Warehouse Proxy Agent and S&P Agents for DB2 password change
#
$SCRIPTS/TWD_password.sh $NEWPASSWD

#
# Change TCR's tipadmin password
#
# First, backup registry XML file
cp $TIPCELL/fileRegistry.xml $TIPCELL/fileRegistry.xml.bak

# Second, change password via wsadmin command but TCR must be running so lets first start it
$TCRBIN/startTCRserver.sh
# Allow TIP to initialize before proceeding with wsadmin command.
sleep 30
$TIPBIN/wsadmin.sh -conntype none -f tipadmin_password.jacl

# Third, restart the Server. Use old password to stop
$TCRBIN/stopTCRserver.sh tipadmin $PASSWD
$TCRBIN/startTCRserver.sh
# Allow TIP to initialize before proceeding with trcmd commands.
sleep 30

# Start the DB2 database, needed for next step
su - db2inst1 -c 'db2start'

#
# Change the TCR JDBC parameters to use new password. TCR must be running for this to work.
#
$TRCMD -user tipadmin -password $NEWPASSWD -modify -dataSources -reportSets -reportSet /TFAM -dataSource name=ITM -setDatasource odaUser=itmuser odaPassword=$NEWPASSWD odaURL="jdbc:db2://localhost:50000/WAREHOUS:currentSchema=ITMUSER;"
$TRCMD -user tipadmin -password $NEWPASSWD -modify -dataSources -reportSets -reportSet /TFAM -dataSource name=AppResourceDS -setDatasource odaUser=itmuser odaPassword=$NEWPASSWD odaURL="jdbc:db2://localhost:50000/WAREHOUS:currentSchema=ITMUSER;"
$TRCMD -user tipadmin -password $NEWPASSWD -modify -dataSources -reportSets -reportSet /TFAM -dataSource name=ExchangeDS -setDatasource odaUser=itmuser odaPassword=$NEWPASSWD odaURL="jdbc:db2://localhost:50000/WAREHOUS:currentSchema=ITMUSER;"

echo "$(date) Finished TCR setup"

echo "Run TFAM_startup.sh to restart appliance processes."


